@@ -411,7 +411,7 @@ void CiscoCertificateEnrollment::next ()
 			ProgressDlg->resize ( ProgressDlg->width() +100,ProgressDlg->height() );
 
 			connect ( &CheckEnrollmentTimer, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( checkProgress() ) );
-			CheckEnrollmentTimer.start ( 500, FALSE );
+			CheckEnrollmentTimer.start ( 500, false );
 
 			// we stupid have to send the password :(
 // 			EnrollmentProcess->writeToStdin ( ChallengePassword + "\n" );
@@ -490,7 +490,7 @@ void CiscoCertificateEnrollment::enrollmentProcessFinished()
 		ProgressDlg->progressBar()->setValue ( 100 );
 	GlobalConfig->appPointer->restoreOverrideCursor();
 	finishpage->SucessTextLabel->setText ( successmsg );
-	finishButton() ->setEnabled ( TRUE );
+	finishButton() ->setEnabled ( true );
 	finishButton() ->setFocus();
 	ProgressDlg->hide();
 // 	delete ProgressDlg;
@@ -553,7 +553,7 @@ void CiscoCertificateEnrollment::readFromStdout()
 			GlobalConfig->appendLogEntry ( "[cisco_cert_mgr raw] "+line,GlobalConfig->debug );
 
 
-		if ( line.find ( "Password:" , 0, FALSE ) > -1 )
+		if ( line.find ( "Password:" , 0, false ) > -1 )
 		{
 			if ( GlobalConfig->KvpncDebugLevel > 0 )
 				GlobalConfig->appendLogEntry ( i18n ( "Certificate enrollment: %1 was requested, send it..." ).arg ( i18n ( " challenge password" ) ),GlobalConfig->debug );
@@ -563,19 +563,19 @@ void CiscoCertificateEnrollment::readFromStdout()
 				GlobalConfig->appendLogEntry ( i18n ( "Send challenge password: %1" ).arg ( ChallengePassword ), KVpncConfig::debug );
 		}
 
-		if ( line.find ( "Request Pending." , 0, FALSE ) > -1 )
+		if ( line.find ( "Request Pending." , 0, false ) > -1 )
 		{
 			if ( ProgressDlg!= 0 )
 				ProgressDlg->progressBar()->setValue ( 66 );
 			GlobalConfig->appendLogEntry ( i18n ( "Certificate enrollment: request sent to CA, waiting for grant..." ) ,GlobalConfig->info );
 		}
-		if ( line.find ( "contacting certificate authority." , 0, FALSE ) > -1 )
+		if ( line.find ( "contacting certificate authority." , 0, false ) > -1 )
 		{
 			GlobalConfig->appendLogEntry ( i18n ( "Certificate enrollment: contacting CA..." ) ,GlobalConfig->info );
 		}
 
 
-		if ( line.find ( "Success: certificate enrollment completed with no errors." , 0, FALSE ) > -1 )
+		if ( line.find ( "Success: certificate enrollment completed with no errors." , 0, false ) > -1 )
 		{
 			if ( ProgressDlg!= 0 )
 				ProgressDlg->progressBar()->setValue ( 99 );
@@ -602,7 +602,7 @@ void CiscoCertificateEnrollment::readFromStderr()
 		if ( GlobalConfig->KvpncDebugLevel > 2 )
 			GlobalConfig->appendLogEntry ( "[cisco_cert_mgr err raw] "+line,GlobalConfig->debug );
 
-		if ( line.find ( "certificate enrollment failed." , 0, FALSE ) > -1 )
+		if ( line.find ( "certificate enrollment failed." , 0, false ) > -1 )
 		{
 
 			KMessageBox::error ( 0, i18n ( "Certificate enrollment: enrollment has been failed." ), i18n ( "Enrollment failed" ) );
