@@ -39,9 +39,9 @@ ProfileCmdExecBeforeConnectOptions::~ProfileCmdExecBeforeConnectOptions()
 void ProfileCmdExecBeforeConnectOptions::execCmdBeforeConnectToggled(bool)
 {
 	if (ExcuteCmdBeforeConnectCheckBox->isChecked())
-		CmdBeforeConnectTextEdit->setEnabled( TRUE );
+		CmdBeforeConnectTextEdit->setEnabled( true );
 	else
-		CmdBeforeConnectTextEdit->setEnabled( FALSE );
+		CmdBeforeConnectTextEdit->setEnabled( false );
 }
 
 void ProfileCmdExecBeforeConnectOptions::dialogChanged()
