@@ -330,32 +330,32 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		//FIXME how it could be better?
 		if (Name == "vpnc")
 		{
-			if ( msg.find( "version", 0, FALSE ) > -1 )
+			if ( msg.find( "version", 0, false ) > -1 )
 			{
 // 												std::cout << "stdout collectToolInfo: " << msg.ascii() << std::endl;
 // 												std::cout << "stdout collectToolInfo: 2,2 " << msg.simplifyWhiteSpace().section(' ',2,2).ascii() << std::endl;
 				Version = msg.simplifyWhiteSpace().section(' ',2,2);
 			}
-			if ( msg.find( "Built without openssl (certificate) support.", 0, FALSE ) > -1 )
+			if ( msg.find( "Built without openssl (certificate) support.", 0, false ) > -1 )
 			{
 // 				Capabilities+=i18n("no openssl support")+";";
 			}
-			else if ( msg.find( "Built with openssl (certificate) support.", 0, FALSE ) > -1 )
+			else if ( msg.find( "Built with openssl (certificate) support.", 0, false ) > -1 )
 			{
 				Capabilities=i18n("openssl (certificate) support")+";";
 			}
 		}
 		else if (Name == "vpnclient" || Name =="cisco_cert_mgr")
 		{
-			if ( msg.find( "Cisco Systems VPN Client", 0, FALSE ) > -1 )
+			if ( msg.find( "Cisco Systems VPN Client", 0, false ) > -1 )
 				Version = msg.section(' ',5,6); // "Cisco Systems VPN Client Version 4.8.00 (0490)"
 		}
 		else if (Name == "ipsec")
 		{
-			if ( msg.find( "wan", 0, FALSE ) > -1 )
+			if ( msg.find( "wan", 0, false ) > -1 )
 			{
 				// 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
-// 				if ( msg.find( "openswan", 0, FALSE ) > -1 )
+// 				if ( msg.find( "openswan", 0, false ) > -1 )
 // 					Version = msg.section(' ',2,2);
 // 				else
 					Version = msg.section(' ',1,2); // "Openswan Ux.x.x/kx.x.x"
@@ -371,7 +371,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 			// we need to do some stupid hack...
 			// /usr/sbin/racoon -> /usr/sbin/setkey
 			CollectToolInfoProcess->addArgument(TQString(PathToExec.left(PathToExec.length()-6)+"setkey"));
-			if ( msg.find( "ipsec-tools", 0, FALSE ) > -1 )
+			if ( msg.find( "ipsec-tools", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',3,3);
@@ -379,7 +379,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "setkey")
 		{
-			if ( msg.find( "ipsec-tools", 0, FALSE ) > -1 )
+			if ( msg.find( "ipsec-tools", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',3,3);
@@ -387,7 +387,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "openvpn")
 		{
-			if ( msg.find( "built", 0, FALSE ) > -1 )
+			if ( msg.find( "built", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',1,1);
@@ -395,7 +395,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "openssl")
 		{
-			if ( msg.find( "OpenSSL", 0, FALSE ) > -1 )
+			if ( msg.find( "OpenSSL", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',1,1);
@@ -403,7 +403,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "pppd")
 		{
-			if ( msg.find( "version", 0, FALSE ) > -1 )
+			if ( msg.find( "version", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',2,2);
@@ -411,7 +411,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "iptables")
 		{
-			if ( msg.find( "iptables", 0, FALSE ) > -1 )
+			if ( msg.find( "iptables", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',1,1);
@@ -419,7 +419,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "ping")
 		{
-			if ( msg.find( "ping", 0, FALSE ) > -1 )
+			if ( msg.find( "ping", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',2,2);
@@ -427,7 +427,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "ip")
 		{
-			if ( msg.find( "ip", 0, FALSE ) > -1 )
+			if ( msg.find( "ip", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',2,2);
@@ -435,7 +435,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "kill")
 		{
-			if ( msg.find( "kill", 0, FALSE ) > -1 )
+			if ( msg.find( "kill", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',3,3).section(')',0,0);
@@ -443,12 +443,12 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "pkcs11-tool")
 		{
-			if ( msg.find( "version", 0, FALSE ) > -1 )
+			if ( msg.find( "version", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',2,2);
 			}
-			else if ( msg.find( "Error: can't open /var/run/openct/status", 0, FALSE ) > -1 )
+			else if ( msg.find( "Error: can't open /var/run/openct/status", 0, false ) > -1 )
 			{
 				std::cerr << "stdout collectToolInfo (pkcs11): " << msg.ascii() << std::endl;
 				CollectToolInfoProcess->kill();
@@ -456,7 +456,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "xl2tpd")
 		{
-			if ( msg.find( "version:", 0, FALSE ) > -1 )
+			if ( msg.find( "version:", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',3,3).stripWhiteSpace();
@@ -464,7 +464,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "openl2tpd")
 		{
-			if ( msg.find( "OpenL2TP V", 0, FALSE ) > -1 )
+			if ( msg.find( "OpenL2TP V", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',1,1).remove(',').remove('V');
@@ -474,7 +474,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "vtund")
 		{
-			if ( msg.find( "VTun ver", 0, FALSE ) > -1 )
+			if ( msg.find( "VTun ver", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',2,3).stripWhiteSpace();
@@ -482,7 +482,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "tail")
 		{
-			if ( msg.find( "tail ", 0, FALSE ) > -1 )
+			if ( msg.find( "tail ", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',3,3).stripWhiteSpace();
@@ -490,7 +490,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "ksshaskpass")
 		{
-			if ( msg.find( "Ksshaskpass:", 0, FALSE ) > -1 )
+			if ( msg.find( "Ksshaskpass:", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',1,1).stripWhiteSpace();
@@ -498,7 +498,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "gnome-ssh-askpass")
 		{
-// 			if ( msg.find( "askpass", 0, FALSE ) > -1 )
+// 			if ( msg.find( "askpass", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
 // 				Version = msg.section(' ',3,3).stripWhiteSpace();
@@ -507,7 +507,7 @@ void ToolInfo::readStdOutCollectToolInfo ()
 		}
 		else	if (Name == "netstat")
 		{
-			if ( msg.find( "netstat ", 0, FALSE ) > -1 )
+			if ( msg.find( "netstat ", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',1,1).stripWhiteSpace();
@@ -534,7 +534,7 @@ void ToolInfo::readStdErrCollectToolInfo()
 
 		if (Name == "pppd")
 		{
-			if ( msg.find( "version", 0, FALSE ) > -1 )
+			if ( msg.find( "version", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',2,2);
@@ -542,7 +542,7 @@ void ToolInfo::readStdErrCollectToolInfo()
 		}
 		else	if (Name == "killall")
 		{
-			if ( msg.find( "killall", 0, FALSE ) > -1 )
+			if ( msg.find( "killall", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',2,2);
@@ -551,7 +551,7 @@ void ToolInfo::readStdErrCollectToolInfo()
 		else	if (Name == "ifconfig")
 		{
 			//KMessageBox::information(0,TQString("Name: "+Name+", Path: "+PathToExec+", Version: "+Version),"aaa");
-			if ( msg.find( "ifconfig", 0, FALSE ) > -1 )
+			if ( msg.find( "ifconfig", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',1,1);
@@ -559,7 +559,7 @@ void ToolInfo::readStdErrCollectToolInfo()
 		}
 		else	if (Name == "route")
 		{
-			if ( msg.find( "route", 0, FALSE ) > -1 )
+			if ( msg.find( "route", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',1,1);
@@ -567,7 +567,7 @@ void ToolInfo::readStdErrCollectToolInfo()
 		}
 		else	if (Name == "pptp")
 		{
-			if ( msg.find( "pptp version", 0, FALSE ) > -1 )
+			if ( msg.find( "pptp version", 0, false ) > -1 )
 			{
 				//				std::cout << "stdout collectToolInfo: " << msg.ascii() << std::endl;
 				Version = msg.section(' ',2,2).section(')',0,0);
@@ -575,7 +575,7 @@ void ToolInfo::readStdErrCollectToolInfo()
 		}
 		else	if (Name == "l2tpd")
 		{
-			if ( msg.find( "l2tpd", 0, FALSE ) > -1 )
+			if ( msg.find( "l2tpd", 0, false ) > -1 )
 			{
 				//std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',2,2).section(')',0,0);
@@ -583,12 +583,12 @@ void ToolInfo::readStdErrCollectToolInfo()
 		}
 		else	if (Name == "pkcs11-tool")
 		{
-			if ( msg.find( "version", 0, FALSE ) > -1 )
+			if ( msg.find( "version", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo (pkcs11): " << msg.ascii() << std::endl;
 				Version = msg.section(' ',2,2);
 			}
-			else if ( msg.find( "Error: can't open /var/run/openct/status", 0, FALSE ) > -1 )
+			else if ( msg.find( "Error: can't open /var/run/openct/status", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo (pkcs11): " << msg.ascii() << std::endl;
 				CollectToolInfoProcess->kill();
@@ -596,7 +596,7 @@ void ToolInfo::readStdErrCollectToolInfo()
 		}
 		else	if (Name == "ssh")
 		{
-			if ( msg.find( "OpenSSH", 0, FALSE ) > -1 )
+			if ( msg.find( "OpenSSH", 0, false ) > -1 )
 			{
 // 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				Version = msg.section(' ',0,0).section('_',1,1).stripWhiteSpace();
@@ -616,7 +616,7 @@ void ToolInfo::readStdOutCollectOpenvpnCapabilies()
 		TQString msg = TQString( CollectOpenvpnCapabilitiesProcess->readLineStdout() );
 		//	TQString msg = TQString( CollectOpenvpnCapabilitiesProcess->readStdout() );
 		// 		std::cout << "stdout collectOpenvpnCapabilities: " << msg.ascii() <<std::endl;
-		if ( msg.find( "PKCS#11 Options:", 0, FALSE ) > -1 )
+		if ( msg.find( "PKCS#11 Options:", 0, false ) > -1 )
 			Capabilities+=i18n("pkcs11 support")+";";
 
 	}
