@@ -28,7 +28,7 @@
 #include <tdelocale.h>
 #include <ksimpleconfig.h>
 #include <tqdir.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <netdb.h> // name resolving
@@ -1416,15 +1416,15 @@ void Utils::readStdErrLoadKernelModule()
 	// 	kdDebug() << "readStdErrreadStderrLoadKernelModule" << msg << endl;
 
 	/* FATAL: Module <Name> not found. */
-	if ( msg.find( "not found", 0, FALSE ) > -1 ) {
+	if ( msg.find( "not found", 0, false ) > -1 ) {
 		modprobeSuccess = false;
 	}
 
-	if ( msg.find( "could not find module", 0 , FALSE ) > -1 ) {
+	if ( msg.find( "could not find module", 0 , false ) > -1 ) {
 		modprobeSuccess = false;
 	}
 
-	if ( msg.find( "not permitted", 0 , FALSE ) > -1 ) {
+	if ( msg.find( "not permitted", 0 , false ) > -1 ) {
 		modprobeSuccess = false;
 	}
 }
@@ -1761,7 +1761,7 @@ void Utils::readOutGetCertsFromCiscoCertStoreSlot()
 // 		if (config->KvpncDebugLevel > 2)
 // 			std::cout << "readOutGetCertsFromCiscoCertStoreSlot: " << msg << std::endl;
 
-		if (msg.find("Cert #",0,FALSE) > -1)
+		if (msg.find("Cert #",0,false) > -1)
 			CertsFromCiscoCertPos=1;
 		if (CertsFromCiscoCertPos==1 || CertsFromCiscoCertPos ==2 | CertsFromCiscoCertPos ==3)
 		{
